@@ -32,7 +32,6 @@ import (
 	"github.com/GoogleCloudPlatform/osconfig/clog"
 	"github.com/GoogleCloudPlatform/osconfig/retryutil"
 	"github.com/GoogleCloudPlatform/osconfig/tasker"
-	"github.com/GoogleCloudPlatform/osconfig/util"
 	"google.golang.org/api/option"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
@@ -68,6 +67,7 @@ func NewClient(ctx context.Context) (*Client, error) {
 		option.WithoutAuthentication(), // Do not use oauth.
 		option.WithGRPCDialOption(grpc.WithTransportCredentials(credentials.NewTLS(nil))), // Because we disabled Auth we need to specifically enable TLS.
 		option.WithEndpoint(agentconfig.SvcEndpoint()),
+		option.WithUserAgent(agentconfig.UserAgent()),
 	}
 	clog.Debugf(ctx, "Creating new agentendpoint client.")
 	c, err := agentendpoint.NewClient(ctx, opts...)
@@ -102,10 +102,13 @@ func (c *Client) RegisterAgent(ctx context.Context) error {
 	}
 
 	req := &agentendpointpb.RegisterAgentRequest{AgentVersion: agentconfig.Version(), SupportedCapabilities: agentconfig.Capabilities()}
-	clog.Debugf(ctx, "Calling RegisterAgent with request:\n%s", util.PrettyFmt(req))
+	req.InstanceIdToken = "<redacted>"
+	clog.DebugRPC(ctx, "RegisterAgent", req, nil)
 	req.InstanceIdToken = token
 
-	_, err = c.raw.RegisterAgent(ctx, req)
+	resp, err := c.raw.RegisterAgent(ctx, req)
+	clog.DebugRPC(ctx, "RegisterAgent", nil, resp)
+
 	return err
 }
 
@@ -128,14 +131,13 @@ func (c *Client) reportInventory(ctx context.Context, inventory *agentendpointpb
 	if reportFull {
 		req = &agentendpointpb.ReportInventoryRequest{InventoryChecksum: checksum, Inventory: inventory}
 	}
-	clog.Debugf(ctx, "Calling ReportInventory with request:\n%s", util.PrettyFmt(req))
+	req.InstanceIdToken = "<redacted>"
+	clog.DebugRPC(ctx, "ReportInventory", req, nil)
 	req.InstanceIdToken = token
 
-	// Additional logging for verifications in e2e tests.
-	payloadSummary := fmt.Sprintf("hostname %s, short name %s, %d installed packages, %d available packages", inventory.OsInfo.Hostname, inventory.OsInfo.ShortName, len(inventory.InstalledPackages), len(inventory.AvailablePackages))
-	clog.Debugf(ctx, "Calling ReportInventory with request containing %s", payloadSummary)
-
-	return c.raw.ReportInventory(ctx, req)
+	resp, err := c.raw.ReportInventory(ctx, req)
+	clog.DebugRPC(ctx, "ReportInventory", nil, resp)
+	return resp, err
 }
 
 func (c *Client) startNextTask(ctx context.Context) (res *agentendpointpb.StartNextTaskResponse, err error) {
@@ -143,22 +145,20 @@ func (c *Client) startNextTask(ctx context.Context) (res *agentendpointpb.StartN
 	if err != nil {
 		return nil, err
 	}
-
 	req := &agentendpointpb.StartNextTaskRequest{}
-	clog.Debugf(ctx, "Calling StartNextTask with request:\n%s", util.PrettyFmt(req))
+	req.InstanceIdToken = "<redacted>"
+	clog.DebugRPC(ctx, "StartNextTask", req, nil)
 	req.InstanceIdToken = token
 
-	if err := retryutil.RetryAPICall(ctx, apiRetrySec*time.Second, "StartNextTask", func() error {
+	err = retryutil.RetryAPICall(ctx, apiRetrySec*time.Second, "StartNextTask", func() error {
 		res, err = c.raw.StartNextTask(ctx, req)
-		if err != nil {
-			return err
-		}
-		clog.Debugf(ctx, "StartNextTask response:\n%s", util.PrettyFmt(res))
-		return nil
-	}); err != nil {
+		return err
+	})
+	clog.DebugRPC(ctx, "StartNextTask", nil, res)
+
+	if err != nil {
 		return nil, fmt.Errorf("error calling StartNextTask: %w", err)
 	}
-
 	return res, nil
 }
 
@@ -167,21 +167,19 @@ func (c *Client) reportTaskProgress(ctx context.Context, req *agentendpointpb.Re
 	if err != nil {
 		return nil, err
 	}
-
-	clog.Debugf(ctx, "Calling ReportTaskProgress with request:\n%s", util.PrettyFmt(req))
+	req.InstanceIdToken = "<redacted>"
+	clog.DebugRPC(ctx, "ReportTaskProgress", req, nil)
 	req.InstanceIdToken = token
 
-	if err := retryutil.RetryAPICall(ctx, apiRetrySec*time.Second, "ReportTaskProgress", func() error {
+	err = retryutil.RetryAPICall(ctx, apiRetrySec*time.Second, "ReportTaskProgress", func() error {
 		res, err = c.raw.ReportTaskProgress(ctx, req)
-		if err != nil {
-			return err
-		}
-		clog.Debugf(ctx, "ReportTaskProgress response:\n%s", util.PrettyFmt(res))
-		return nil
-	}); err != nil {
+		return err
+	})
+	clog.DebugRPC(ctx, "ReportTaskProgress", nil, res)
+
+	if err != nil {
 		return nil, fmt.Errorf("error calling ReportTaskProgress: %w", err)
 	}
-
 	return res, nil
 }
 
@@ -190,21 +188,20 @@ func (c *Client) reportTaskComplete(ctx context.Context, req *agentendpointpb.Re
 	if err != nil {
 		return err
 	}
-
-	clog.Debugf(ctx, "Calling ReportTaskComplete with request:\n%s", util.PrettyFmt(req))
+	req.InstanceIdToken = "<redacted>"
+	clog.DebugRPC(ctx, "ReportTaskComplete", req, nil)
 	req.InstanceIdToken = token
 
-	if err := retryutil.RetryAPICall(ctx, apiRetrySec*time.Second, "ReportTaskComplete", func() error {
-		res, err := c.raw.ReportTaskComplete(ctx, req)
-		if err != nil {
-			return err
-		}
-		clog.Debugf(ctx, "ReportTaskComplete response:\n%s", util.PrettyFmt(res))
-		return nil
-	}); err != nil {
+	var res *agentendpointpb.ReportTaskCompleteResponse
+	err = retryutil.RetryAPICall(ctx, apiRetrySec*time.Second, "ReportTaskComplete", func() error {
+		res, err = c.raw.ReportTaskComplete(ctx, req)
+		return err
+	})
+	clog.DebugRPC(ctx, "ReportTaskComplete", nil, res)
+
+	if err != nil {
 		return fmt.Errorf("error calling ReportTaskComplete: %w", err)
 	}
-
 	return nil
 }
 
@@ -224,6 +221,7 @@ func (c *Client) runTask(ctx context.Context) {
 		}
 
 		clog.Debugf(ctx, "Received task: %s.", task.GetTaskType())
+		ctx = clog.WithLabels(ctx, map[string]string{"task_type": task.GetTaskType().String()})
 		switch task.GetTaskType() {
 		case agentendpointpb.TaskType_APPLY_PATCHES:
 			if err := c.RunApplyPatches(ctx, task); err != nil {
@@ -281,19 +279,21 @@ func (c *Client) handleStream(ctx context.Context, stream agentendpointpb.AgentE
 }
 
 func (c *Client) receiveTaskNotification(ctx context.Context) (agentendpointpb.AgentEndpointService_ReceiveTaskNotificationClient, error) {
-	req := &agentendpointpb.ReceiveTaskNotificationRequest{
-		AgentVersion: agentconfig.Version(),
-	}
-
 	token, err := agentconfig.IDToken()
 	if err != nil {
 		return nil, fmt.Errorf("error fetching Instance IDToken: %w", err)
 	}
 
-	clog.Debugf(ctx, "Calling ReceiveTaskNotification with request:\n%s", util.PrettyFmt(req))
+	req := &agentendpointpb.ReceiveTaskNotificationRequest{
+		AgentVersion: agentconfig.Version(),
+	}
+
+	req.InstanceIdToken = "<redacted>"
+	clog.DebugRPC(ctx, "ReceiveTaskNotification", req, nil)
 	req.InstanceIdToken = token
 
-	return c.raw.ReceiveTaskNotification(ctx, req)
+	resp, err := c.raw.ReceiveTaskNotification(ctx, req)
+	return resp, err
 }
 
 func (c *Client) loadTaskFromState(ctx context.Context) error {
