@@ -84,16 +84,16 @@ func generateInventoryState(shortName string) *inventory.InstanceInventory {
 		KernelRelease:        "KernelRelease",
 		OSConfigAgentVersion: "OSConfigAgentVersion",
 		InstalledPackages: &packages.Packages{
-			Yum:           []packages.PkgInfo{{Name: "YumInstalledPkg", Arch: "Arch", Version: "Version"}},
-			Rpm:           []packages.PkgInfo{{Name: "RpmInstalledPkg", Arch: "Arch", Version: "Version"}},
-			Apt:           []packages.PkgInfo{{Name: "AptInstalledPkg", Arch: "Arch", Version: "Version"}},
-			Deb:           []packages.PkgInfo{{Name: "DebInstalledPkg", Arch: "Arch", Version: "Version"}},
-			Zypper:        []packages.PkgInfo{{Name: "ZypperInstalledPkg", Arch: "Arch", Version: "Version"}},
-			ZypperPatches: []packages.ZypperPatch{{Name: "ZypperInstalledPatch", Category: "Category", Severity: "Severity", Summary: "Summary"}},
-			Gem:           []packages.PkgInfo{{Name: "GemInstalledPkg", Arch: "Arch", Version: "Version"}},
-			Pip:           []packages.PkgInfo{{Name: "PipInstalledPkg", Arch: "Arch", Version: "Version"}},
-			GooGet:        []packages.PkgInfo{{Name: "GooGetInstalledPkg", Arch: "Arch", Version: "Version"}},
-			WUA: []packages.WUAPackage{{
+			Yum:           []*packages.PkgInfo{{Name: "YumInstalledPkg", Arch: "Arch", Version: "Version"}},
+			Rpm:           []*packages.PkgInfo{{Name: "RpmInstalledPkg", Arch: "Arch", Version: "Version"}},
+			Apt:           []*packages.PkgInfo{{Name: "AptInstalledPkg", Arch: "Arch", Version: "Version"}},
+			Deb:           []*packages.PkgInfo{{Name: "DebInstalledPkg", Arch: "Arch", Version: "Version"}},
+			Zypper:        []*packages.PkgInfo{{Name: "ZypperInstalledPkg", Arch: "Arch", Version: "Version"}},
+			ZypperPatches: []*packages.ZypperPatch{{Name: "ZypperInstalledPatch", Category: "Category", Severity: "Severity", Summary: "Summary"}},
+			Gem:           []*packages.PkgInfo{{Name: "GemInstalledPkg", Arch: "Arch", Version: "Version"}},
+			Pip:           []*packages.PkgInfo{{Name: "PipInstalledPkg", Arch: "Arch", Version: "Version"}},
+			GooGet:        []*packages.PkgInfo{{Name: "GooGetInstalledPkg", Arch: "Arch", Version: "Version"}},
+			WUA: []*packages.WUAPackage{{
 				Title:                    "WUAInstalled",
 				Description:              "Description",
 				Categories:               []string{"Category"},
@@ -104,20 +104,20 @@ func generateInventoryState(shortName string) *inventory.InstanceInventory {
 				UpdateID:                 "UpdateID",
 				RevisionNumber:           1,
 				LastDeploymentChangeTime: time.Date(2020, time.November, 10, 23, 0, 0, 0, time.UTC)}},
-			QFE: []packages.QFEPackage{{Caption: "QFEInstalled", Description: "Description", HotFixID: "HotFixID", InstalledOn: "9/1/2020"}},
-			COS: []packages.PkgInfo{{Name: "CosInstalledPkg", Arch: "Arch", Version: "Version"}},
+			QFE: []*packages.QFEPackage{{Caption: "QFEInstalled", Description: "Description", HotFixID: "HotFixID", InstalledOn: "9/1/2020"}},
+			COS: []*packages.PkgInfo{{Name: "CosInstalledPkg", Arch: "Arch", Version: "Version"}},
 		},
 		PackageUpdates: &packages.Packages{
-			Yum:           []packages.PkgInfo{{Name: "YumPkgUpdate", Arch: "Arch", Version: "Version"}},
-			Rpm:           []packages.PkgInfo{{Name: "RpmPkgUpdate", Arch: "Arch", Version: "Version"}},
-			Apt:           []packages.PkgInfo{{Name: "AptPkgUpdate", Arch: "Arch", Version: "Version"}},
-			Deb:           []packages.PkgInfo{{Name: "DebPkgUpdate", Arch: "Arch", Version: "Version"}},
-			Zypper:        []packages.PkgInfo{{Name: "ZypperPkgUpdate", Arch: "Arch", Version: "Version"}},
-			ZypperPatches: []packages.ZypperPatch{{Name: "ZypperPatchUpdate", Category: "Category", Severity: "Severity", Summary: "Summary"}},
-			Gem:           []packages.PkgInfo{{Name: "GemPkgUpdate", Arch: "Arch", Version: "Version"}},
-			Pip:           []packages.PkgInfo{{Name: "PipPkgUpdate", Arch: "Arch", Version: "Version"}},
-			GooGet:        []packages.PkgInfo{{Name: "GooGetPkgUpdate", Arch: "Arch", Version: "Version"}},
-			WUA: []packages.WUAPackage{{
+			Yum:           []*packages.PkgInfo{{Name: "YumPkgUpdate", Arch: "Arch", Version: "Version"}},
+			Rpm:           []*packages.PkgInfo{{Name: "RpmPkgUpdate", Arch: "Arch", Version: "Version"}},
+			Apt:           []*packages.PkgInfo{{Name: "AptPkgUpdate", Arch: "Arch", Version: "Version"}},
+			Deb:           []*packages.PkgInfo{{Name: "DebPkgUpdate", Arch: "Arch", Version: "Version"}},
+			Zypper:        []*packages.PkgInfo{{Name: "ZypperPkgUpdate", Arch: "Arch", Version: "Version"}},
+			ZypperPatches: []*packages.ZypperPatch{{Name: "ZypperPatchUpdate", Category: "Category", Severity: "Severity", Summary: "Summary"}},
+			Gem:           []*packages.PkgInfo{{Name: "GemPkgUpdate", Arch: "Arch", Version: "Version"}},
+			Pip:           []*packages.PkgInfo{{Name: "PipPkgUpdate", Arch: "Arch", Version: "Version"}},
+			GooGet:        []*packages.PkgInfo{{Name: "GooGetPkgUpdate", Arch: "Arch", Version: "Version"}},
+			WUA: []*packages.WUAPackage{{
 				Title:                    "WUAUpdate",
 				Description:              "Description",
 				Categories:               []string{"Category"},
@@ -128,8 +128,8 @@ func generateInventoryState(shortName string) *inventory.InstanceInventory {
 				UpdateID:                 "UpdateID",
 				RevisionNumber:           1,
 				LastDeploymentChangeTime: time.Time{}}},
-			QFE: []packages.QFEPackage{{Caption: "QFEUpdate", Description: "Description", HotFixID: "HotFixID", InstalledOn: "InvalidDate"}},
-			COS: []packages.PkgInfo{{Name: "CosInstalledPkg", Arch: "Arch", Version: "Version"}},
+			QFE: []*packages.QFEPackage{{Caption: "QFEUpdate", Description: "Description", HotFixID: "HotFixID", InstalledOn: "InvalidDate"}},
+			COS: []*packages.PkgInfo{{Name: "CosInstalledPkg", Arch: "Arch", Version: "Version"}},
 		},
 	}
 }
@@ -336,12 +336,12 @@ func TestWrite(t *testing.T) {
 		KernelRelease: "KernelRelease",
 		Version:       "Version",
 		InstalledPackages: &packages.Packages{
-			Yum: []packages.PkgInfo{{Name: "Name", Arch: "Arch", Version: "Version"}},
-			WUA: []packages.WUAPackage{{Title: "Title"}},
-			QFE: []packages.QFEPackage{{HotFixID: "HotFixID"}},
+			Yum: []*packages.PkgInfo{{Name: "Name", Arch: "Arch", Version: "Version"}},
+			WUA: []*packages.WUAPackage{{Title: "Title"}},
+			QFE: []*packages.QFEPackage{{HotFixID: "HotFixID"}},
 		},
 		PackageUpdates: &packages.Packages{
-			Apt: []packages.PkgInfo{{Name: "Name", Arch: "Arch", Version: "Version"}},
+			Apt: []*packages.PkgInfo{{Name: "Name", Arch: "Arch", Version: "Version"}},
 		},
 		OSConfigAgentVersion: "OSConfigAgentVersion",
 		LastUpdated:          "LastUpdated",
