@@ -48,7 +48,7 @@ func buildPkgInstallTestSetup(name, image, pkgManager, key string) *guestPolicyT
 	assertTimeout := 120 * time.Second
 	testName := packageInstallFunction
 	packageName := "ed"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		packageName = "cowsay"
 		machineType = "e2-standard-4"
@@ -63,7 +63,7 @@ func buildPkgInstallTestSetup(name, image, pkgManager, key string) *guestPolicyT
 		Assignment: &osconfigpb.Assignment{InstanceNamePrefixes: []string{instanceName}},
 	}
 	ss := getStartupScript(name, pkgManager, packageName)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func addPackageInstallTest(key string) []*guestPolicyTestSetup {
@@ -87,7 +87,7 @@ func buildPkgUpdateTestSetup(name, image, pkgManager, key string) *guestPolicyTe
 	assertTimeout := 240 * time.Second
 	testName := packageUpdateFunction
 	packageName := "ed"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		packageName = "cowsay"
 		machineType = "e2-standard-4"
@@ -98,7 +98,7 @@ func buildPkgUpdateTestSetup(name, image, pkgManager, key string) *guestPolicyTe
 		Assignment: &osconfigpb.Assignment{InstanceNamePrefixes: []string{instanceName}},
 	}
 	ss := getUpdateStartupScript(name, pkgManager)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageNotInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageNotInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func addPackageUpdateTest(key string) []*guestPolicyTestSetup {
@@ -122,7 +122,7 @@ func buildPkgDoesNotUpdateTestSetup(name, image, pkgManager, key string) *guestP
 	assertTimeout := 240 * time.Second
 	testName := packageNoUpdateFunction
 	packageName := "ed"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		packageName = "cowsay"
 		machineType = "e2-standard-4"
@@ -134,7 +134,7 @@ func buildPkgDoesNotUpdateTestSetup(name, image, pkgManager, key string) *guestP
 		Assignment: &osconfigpb.Assignment{InstanceNamePrefixes: []string{instanceName}},
 	}
 	ss := getUpdateStartupScript(name, pkgManager)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func addPackageDoesNotUpdateTest(key string) []*guestPolicyTestSetup {
@@ -158,7 +158,7 @@ func buildPkgRemoveTestSetup(name, image, pkgManager, key string) *guestPolicyTe
 	assertTimeout := 180 * time.Second
 	testName := packageRemovalFunction
 	packageName := "vim"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if pkgManager == "googet" {
 		packageName = "certgen"
 		machineType = "e2-standard-4"
@@ -170,7 +170,7 @@ func buildPkgRemoveTestSetup(name, image, pkgManager, key string) *guestPolicyTe
 		Assignment: &osconfigpb.Assignment{InstanceNamePrefixes: []string{instanceName}},
 	}
 	ss := getStartupScript(name, pkgManager, packageName)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageNotInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageNotInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func addPackageRemovalTest(key string) []*guestPolicyTestSetup {
@@ -194,9 +194,9 @@ func buildPkgInstallFromNewRepoTestSetup(name, image, pkgManager, key string) *g
 	assertTimeout := 120 * time.Second
 	packageName := "osconfig-agent-test"
 	testName := packageInstallFromNewRepoFunction
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if pkgManager == "googet" {
-		machineType = "e2-standard-4"
+		machineType = "e2-standard-2"
 	}
 
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
@@ -212,7 +212,7 @@ func buildPkgInstallFromNewRepoTestSetup(name, image, pkgManager, key string) *g
 		},
 	}
 	ss := getStartupScript(name, pkgManager, packageName)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func addPackageInstallFromNewRepoTest(key string) []*guestPolicyTestSetup {
@@ -282,7 +282,7 @@ func buildRecipeInstallTestSetup(name, image, pkgManager, key string) *guestPoli
 	assertTimeout := 120 * time.Second
 	testName := recipeInstallFunction
 	recipeName := "testrecipe"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if strings.HasPrefix(image, "windows") {
 		machineType = "e2-standard-4"
 	}
@@ -295,7 +295,7 @@ func buildRecipeInstallTestSetup(name, image, pkgManager, key string) *guestPoli
 		},
 	}
 	ss := getRecipeInstallStartupScript(name, recipeName, pkgManager)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func addRecipeStepsTest(key string) []*guestPolicyTestSetup {
@@ -325,9 +325,9 @@ func buildRecipeStepsTestSetup(name, image, pkgManager, key string) *guestPolicy
 	assertTimeout := 120 * time.Second
 	testName := recipeStepsFunction
 	recipeName := "testrecipe"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if strings.HasPrefix(image, "windows") {
-		machineType = "e2-standard-4"
+		machineType = "e2-standard-2"
 	}
 
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
@@ -420,14 +420,14 @@ func buildRecipeStepsTestSetup(name, image, pkgManager, key string) *guestPolicy
 		Recipes: []*osconfigpb.SoftwareRecipe{
 			osconfigserver.BuildSoftwareRecipe(recipeName, "", artifacts,
 				[]*osconfigpb.SoftwareRecipe_Step{
-					&osconfigpb.SoftwareRecipe_Step{Step: &osconfigpb.SoftwareRecipe_Step_ScriptRun{
+					{Step: &osconfigpb.SoftwareRecipe_Step_ScriptRun{
 						ScriptRun: &osconfigpb.SoftwareRecipe_Step_RunScript{
 							Script:      "echo 'hello world' > /tmp/osconfig-SoftwareRecipe_Step_RunScript_SHELL",
 							Interpreter: osconfigpb.SoftwareRecipe_Step_RunScript_SHELL,
 						},
 					}},
 
-					&osconfigpb.SoftwareRecipe_Step{Step: &osconfigpb.SoftwareRecipe_Step_FileCopy{
+					{Step: &osconfigpb.SoftwareRecipe_Step_FileCopy{
 						FileCopy: &osconfigpb.SoftwareRecipe_Step_CopyFile{ArtifactId: "copy-test", Destination: "/tmp/osconfig-copy-test"},
 					}},
 					{Step: &osconfigpb.SoftwareRecipe_Step_ArchiveExtraction{
@@ -489,22 +489,22 @@ func buildRecipeStepsTestSetup(name, image, pkgManager, key string) *guestPolicy
 	}
 
 	ss := getRecipeStepsStartupScript(name, recipeName, pkgManager)
-	return newGuestPolicyTestSetup(image, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
+	return newGuestPolicyTestSetup(image, name, instanceName, testName, packageInstalled, machineType, gp, ss, assertTimeout)
 }
 
 func buildMetadataPolicyTestSetup(name, image, pkgManager, key string) *guestPolicyTestSetup {
 	assertTimeout := 60 * time.Second
 	testName := metadataPolicyFunction
 	recipeName := "testrecipe"
-	machineType := "e2-standard-2"
+	machineType := "e2-medium"
 	if strings.HasPrefix(image, "windows") {
-		machineType = "e2-standard-4"
+		machineType = "e2-standard-2"
 	}
 
 	instanceName := fmt.Sprintf("%s-%s-%s-%s", path.Base(name), testName, key, utils.RandString(3))
 
 	ss := getRecipeInstallStartupScript(name, recipeName, pkgManager)
-	ts := newGuestPolicyTestSetup(image, instanceName, testName, packageInstalled, machineType, nil, ss, assertTimeout)
+	ts := newGuestPolicyTestSetup(image, name, instanceName, testName, packageInstalled, machineType, nil, ss, assertTimeout)
 
 	marshaler := jsonpb.Marshaler{}
 	recipeString, err := marshaler.MarshalToString(osconfigserver.BuildSoftwareRecipe(recipeName, "", nil, nil))
