@@ -32,7 +32,7 @@ func runService(ctx context.Context) {
 func obtainLock() {
 	lockFile := "/run/lock/osconfig_agent.lock"
 
-	err := os.MkdirAll(filepath.Dir(lockFile), 0755)
+	err := os.Mkdir(filepath.Dir(lockFile), 1777)
 	if err != nil && !os.IsExist(err) {
 		logger.Fatalf("Cannot obtain agent lock: %v", err)
 	}
