@@ -30,10 +30,10 @@ var (
 )
 
 type yumUpdateOpts struct {
-	security          bool
-	minimal           bool
 	exclusivePackages []string
 	excludes          []string
+	security          bool
+	minimal           bool
 	dryrun            bool
 }
 
@@ -111,7 +111,7 @@ func RunYumUpdate(ctx context.Context, opts ...YumUpdateOption) error {
 		pkgNames = append(pkgNames, pkg.Name)
 	}
 
-	msg := fmt.Sprintf("%d packages: %s", len(pkgNames), fPkgs)
+	msg := fmt.Sprintf("%d packages: %v", len(pkgNames), fPkgs)
 	if yumOpts.dryrun {
 		clog.Infof(ctx, "Running in dryrun mode, not updating %s", msg)
 		return nil
