@@ -31,7 +31,7 @@ func TestParseInstalledCOSPackages(t *testing.T) {
 	readMachineArch = func() (string, error) {
 		return "", errors.New("failed to obtain machine architecture")
 	}
-	if _, err := parseInstalledCOSPackages(cos.PackageInfo{}); err == nil {
+	if _, err := parseInstalledCOSPackages(&cos.PackageInfo{}); err == nil {
 		t.Errorf("did not get expected error")
 	}
 
@@ -39,12 +39,12 @@ func TestParseInstalledCOSPackages(t *testing.T) {
 		return "x86_64", nil
 	}
 
-	pkg0 := cos.Package{Category: "dev-util", Name: "foo-x", Version: "1.2.3", Revision: 4}
-	expect0 := PkgInfo{"dev-util/foo-x", "x86_64", "1.2.3-r4"}
-	pkg1 := cos.Package{Category: "app-admin", Name: "bar", Version: "0.1", Revision: 0}
-	expect1 := PkgInfo{"app-admin/bar", "x86_64", "0.1"}
+	pkg0 := cos.Package{Category: "dev-util", Name: "foo-x", Version: "1.2.3", EbuildVersion: "someversion"}
+	expect0 := &PkgInfo{"dev-util/foo-x", "x86_64", "1.2.3"}
+	pkg1 := cos.Package{Category: "app-admin", Name: "bar", Version: "0.1"}
+	expect1 := &PkgInfo{"app-admin/bar", "x86_64", "0.1"}
 
-	pkgInfo := cos.PackageInfo{InstalledPackages: []cos.Package{pkg0, pkg1}}
+	pkgInfo := &cos.PackageInfo{InstalledPackages: []cos.Package{pkg0, pkg1}}
 	parsed, err := parseInstalledCOSPackages(pkgInfo)
 	if err != nil {
 		t.Errorf("unexpected error: %v", err)
@@ -63,19 +63,18 @@ func TestInstalledCOSPackages(t *testing.T) {
         {
             "category": "app-arch",
             "name": "gzip",
-            "version": "1.9"
+            "version": "1.9",
+			"ebuildverison": "someotherversion"
         },
         {
             "category": "dev-libs",
             "name": "popt",
-            "version": "1.16",
-            "revision": "2"
+            "version": "1.16"
         },
         {
             "category": "app-emulation",
             "name": "docker-credential-helpers",
-            "version": "0.6.3",
-            "revision": "1"
+            "version": "0.6.3"
         },
         {
             "category": "_not.real-category1+",
@@ -85,8 +84,7 @@ func TestInstalledCOSPackages(t *testing.T) {
         {
             "category": "_not.real-category1+",
             "name": "_not-real_package2",
-            "version": "12.34.56.78",
-            "revision": "26"
+            "version": "12.34.56.78"
         },
         {
             "category": "_not.real-category1+",
@@ -96,14 +94,12 @@ func TestInstalledCOSPackages(t *testing.T) {
         {
             "category": "_not.real-category1+",
             "name": "_not-real_package4",
-            "version": "12.34.56.78_rc3",
-            "revision": "26"
+            "version": "12.34.56.78_rc3"
         },
         {
             "category": "_not.real-category1+",
             "name": "_not-real_package5",
-            "version": "12.34.56.78_pre2_rc3",
-            "revision": "26"
+            "version": "12.34.56.78_pre2_rc3"
         },
         {
             "category": "_not.real-category2+",
@@ -113,8 +109,7 @@ func TestInstalledCOSPackages(t *testing.T) {
         {
             "category": "_not.real-category2+",
             "name": "_not-real_package2",
-            "version": "12.34.56.78q",
-            "revision": "26"
+            "version": "12.34.56.78q"
         },
         {
             "category": "_not.real-category2+",
@@ -124,14 +119,12 @@ func TestInstalledCOSPackages(t *testing.T) {
         {
             "category": "_not.real-category2+",
             "name": "_not-real_package4",
-            "version": "12.34.56.78q_rc3",
-            "revision": "26"
+            "version": "12.34.56.78q_rc3"
         },
         {
             "category": "_not.real-category2+",
             "name": "_not-real_package5",
-            "version": "12.34.56.78q_pre2_rc3",
-            "revision": "26"
+            "version": "12.34.56.78q_pre2_rc3"
         }
     ]
 }`
@@ -150,27 +143,28 @@ func TestInstalledCOSPackages(t *testing.T) {
 		t.Fatalf("Failed to close test file: %v", err)
 	}
 
-	expected := []PkgInfo{
+	expected := []*PkgInfo{
 		{"app-arch/gzip", "x86_64", "1.9"},
-		{"dev-libs/popt", "x86_64", "1.16-r2"},
-		{"app-emulation/docker-credential-helpers", "x86_64", "0.6.3-r1"},
+		{"dev-libs/popt", "x86_64", "1.16"},
+		{"app-emulation/docker-credential-helpers", "x86_64", "0.6.3"},
 		{"_not.real-category1+/_not-real_package1", "x86_64", "12.34.56.78"},
-		{"_not.real-category1+/_not-real_package2", "x86_64", "12.34.56.78-r26"},
+		{"_not.real-category1+/_not-real_package2", "x86_64", "12.34.56.78"},
 		{"_not.real-category1+/_not-real_package3", "x86_64", "12.34.56.78_rc3"},
-		{"_not.real-category1+/_not-real_package4", "x86_64", "12.34.56.78_rc3-r26"},
-		{"_not.real-category1+/_not-real_package5", "x86_64", "12.34.56.78_pre2_rc3-r26"},
+		{"_not.real-category1+/_not-real_package4", "x86_64", "12.34.56.78_rc3"},
+		{"_not.real-category1+/_not-real_package5", "x86_64", "12.34.56.78_pre2_rc3"},
 		{"_not.real-category2+/_not-real_package1", "x86_64", "12.34.56.78q"},
-		{"_not.real-category2+/_not-real_package2", "x86_64", "12.34.56.78q-r26"},
+		{"_not.real-category2+/_not-real_package2", "x86_64", "12.34.56.78q"},
 		{"_not.real-category2+/_not-real_package3", "x86_64", "12.34.56.78q_rc3"},
-		{"_not.real-category2+/_not-real_package4", "x86_64", "12.34.56.78q_rc3-r26"},
-		{"_not.real-category2+/_not-real_package5", "x86_64", "12.34.56.78q_pre2_rc3-r26"},
+		{"_not.real-category2+/_not-real_package4", "x86_64", "12.34.56.78q_rc3"},
+		{"_not.real-category2+/_not-real_package5", "x86_64", "12.34.56.78q_pre2_rc3"},
 	}
 
 	readMachineArch = func() (string, error) {
 		return "", errors.New("failed to obtain machine architecture")
 	}
-	readCOSPackageInfo = func() (cos.PackageInfo, error) {
-		return cos.GetPackageInfoFromFile(testFile.Name())
+	readCOSPackageInfo = func() (*cos.PackageInfo, error) {
+		info, err := cos.GetPackageInfoFromFile(testFile.Name())
+		return &info, err
 	}
 	if _, err := InstalledCOSPackages(); err == nil {
 		t.Errorf("did not get expected error from readMachineArch")
@@ -179,8 +173,9 @@ func TestInstalledCOSPackages(t *testing.T) {
 	readMachineArch = func() (string, error) {
 		return "x86_64", nil
 	}
-	readCOSPackageInfo = func() (cos.PackageInfo, error) {
-		return cos.GetPackageInfoFromFile("_" + testFile.Name())
+	readCOSPackageInfo = func() (*cos.PackageInfo, error) {
+		info, err := cos.GetPackageInfoFromFile("_" + testFile.Name())
+		return &info, err
 	}
 	if _, err := InstalledCOSPackages(); err == nil {
 		t.Errorf("did not get expected error fro readCOSPackageInfo")
@@ -189,8 +184,9 @@ func TestInstalledCOSPackages(t *testing.T) {
 	readMachineArch = func() (string, error) {
 		return "x86_64", nil
 	}
-	readCOSPackageInfo = func() (cos.PackageInfo, error) {
-		return cos.GetPackageInfoFromFile(testFile.Name())
+	readCOSPackageInfo = func() (*cos.PackageInfo, error) {
+		info, err := cos.GetPackageInfoFromFile(testFile.Name())
+		return &info, err
 	}
 	ret, err := InstalledCOSPackages()
 	if err != nil {
