@@ -66,12 +66,12 @@ func TestParseInstalledGooGetPackages(t *testing.T) {
 	tests := []struct {
 		name string
 		data []byte
-		want []PkgInfo
+		want []*PkgInfo
 	}{
-		{"NormalCase", []byte(" Installed Packages:\nfoo.x86_64 1.2.3@4\nbar.noarch 1.2.3@4"), []PkgInfo{{"foo", "x86_64", "1.2.3@4"}, {"bar", "noarch", "1.2.3@4"}}},
+		{"NormalCase", []byte(" Installed Packages:\nfoo.x86_64 1.2.3@4\nbar.noarch 1.2.3@4"), []*PkgInfo{{"foo", "x86_64", "1.2.3@4"}, {"bar", "noarch", "1.2.3@4"}}},
 		{"NoPackages", []byte("nothing here"), nil},
 		{"nil", nil, nil},
-		{"UnrecognizedPackage", []byte("Inst something we dont understand\n foo.x86_64 1.2.3@4"), []PkgInfo{{"foo", "x86_64", "1.2.3@4"}}},
+		{"UnrecognizedPackage", []byte("Inst something we dont understand\n foo.x86_64 1.2.3@4"), []*PkgInfo{{"foo", "x86_64", "1.2.3@4"}}},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -96,7 +96,7 @@ func TestInstalledGooGetPackages(t *testing.T) {
 		t.Errorf("unexpected error: %v", err)
 	}
 
-	want := []PkgInfo{{"foo", "x86_64", "1.2.3@4"}}
+	want := []*PkgInfo{{"foo", "x86_64", "1.2.3@4"}}
 	if !reflect.DeepEqual(ret, want) {
 		t.Errorf("InstalledGooGetPackages() = %v, want %v", ret, want)
 	}
@@ -111,12 +111,12 @@ func TestParseGooGetUpdates(t *testing.T) {
 	tests := []struct {
 		name string
 		data []byte
-		want []PkgInfo
+		want []*PkgInfo
 	}{
-		{"NormalCase", []byte("Searching for available updates...\nfoo.noarch, 3.5.4@1 --> 3.6.7@1 from repo\nbar.x86_64, 1.0.0@1 --> 2.0.0@1 from repo\nPerform update? (y/N):"), []PkgInfo{{"foo", "noarch", "3.6.7@1"}, {"bar", "x86_64", "2.0.0@1"}}},
+		{"NormalCase", []byte("Searching for available updates...\nfoo.noarch, 3.5.4@1 --> 3.6.7@1 from repo\nbar.x86_64, 1.0.0@1 --> 2.0.0@1 from repo\nPerform update? (y/N):"), []*PkgInfo{{"foo", "noarch", "3.6.7@1"}, {"bar", "x86_64", "2.0.0@1"}}},
 		{"NoPackages", []byte("nothing here"), nil},
 		{"nil", nil, nil},
-		{"UnrecognizedPackage", []byte("Inst something we dont understand\n foo.noarch, 3.5.4@1 --> 3.6.7@1 from repo"), []PkgInfo{{"foo", "noarch", "3.6.7@1"}}},
+		{"UnrecognizedPackage", []byte("Inst something we dont understand\n foo.noarch, 3.5.4@1 --> 3.6.7@1 from repo"), []*PkgInfo{{"foo", "noarch", "3.6.7@1"}}},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -141,7 +141,7 @@ func TestGooGetUpdates(t *testing.T) {
 		t.Errorf("unexpected error: %v", err)
 	}
 
-	want := []PkgInfo{{"foo", "noarch", "3.6.7@1"}}
+	want := []*PkgInfo{{"foo", "noarch", "3.6.7@1"}}
 	if !reflect.DeepEqual(ret, want) {
 		t.Errorf("GooGetUpdates() = %v, want %v", ret, want)
 	}
