@@ -32,8 +32,6 @@ import (
 	"time"
 
 	"github.com/GoogleCloudPlatform/osconfig/clog"
-	"google.golang.org/protobuf/encoding/protojson"
-	"google.golang.org/protobuf/proto"
 )
 
 // Logger holds log functions.
@@ -45,12 +43,6 @@ type Logger struct {
 	Fatalf   func(string, ...interface{})
 }
 
-// PrettyFmt uses jsonpb to marshal a proto for pretty printing.
-func PrettyFmt(pb proto.Message) string {
-	m := &protojson.MarshalOptions{Indent: "  ", AllowPartial: true, UseProtoNames: true, EmitUnpopulated: true, UseEnumNumbers: false}
-	return m.Format(pb)
-}
-
 // NormPath transforms a windows path into an extended-length path as described in
 // https://msdn.microsoft.com/en-us/library/windows/desktop/aa365247(v=vs.85).aspx#maxpath
 // when not running on windows it will just return the input path.
@@ -137,7 +129,7 @@ func (r *DefaultRunner) Run(ctx context.Context, cmd *exec.Cmd) ([]byte, []byte,
 	cmd.Stdout = &stdout
 	cmd.Stderr = &stderr
 	err := cmd.Run()
-	clog.Debugf(ctx, "%s %q output:\n%s", cmd.Path, cmd.Args[1:], strings.ReplaceAll(stdout.String(), "\n", "\n "))
+	clog.Debugf(ctx, "%s %q exit code: %d, output:\n%s", cmd.Path, cmd.Args[1:], cmd.ProcessState.ExitCode(), strings.ReplaceAll(stdout.String(), "\n", "\n "))
 	return stdout.Bytes(), stderr.Bytes(), err
 }
 
